#!/bin/bash

# Make sure only root can run this script
if [ "$(id -u)" != "0" ]; then
   echo " - You must prepend 'sudo' !" 1>&2
   exit 1
fi

echo -e '\n- Set DNS servers / Restore default -\n' ;

# these are Cloudflare's DNS servers
CLF_one=1.1.1.1
CLF_two=1.0.0.1

# these are OpenDNS servers
OPE_one=208.67.222.222
OPE_two=208.67.220.220

PS3='
Please enter your choice : '
options=(" Cloudflare" " OpenDNS" " Custom DNS" " Restore OS" " Quit")
select opt in "${options[@]}"
do
	case $opt in
	" Cloudflare")
		# search the default string
		if grep -qs 'dns=dnsmasq' /etc/NetworkManager/NetworkManager.conf

		then

			# -------------------- runs if found default dns settings -------------------- 

			# mount root in read/write mode
			mount -o remount,rw / ;

			# remove /etc/resolv.conf (is a symbolic link pointing to /run/resolvconf/resolv.conf)
			rm /etc/resolv.conf ;

			# create /etc/resolv.conf
			touch /etc/resolv.conf ;

			# add it Cloudflare servers
			echo -e "nameserver $CLF_one\nnameserver $CLF_two" >> /etc/resolv.conf ;

			# set permission
			chmod 644 /etc/resolv.conf ;

			# make it immutable
			chattr +i /etc/resolv.conf ;

			# replace dns=dnsmasq  with  dns=none in NetworkManager conf file
			sed -i 's/dns=dnsmasq/dns=none/' /etc/NetworkManager/NetworkManager.conf ;

			# remount root in read only mode
			mount -o remount,ro / ;

			echo -e '\n Cloudflare DNS are set up !\n'

			exit 0

		else

			# -------------------- runs if dns settings are already changed --------------------

			# mount root in read/write mode
			mount -o remount,rw / ;

			# makes /etc/resolv.conf writable/erasable
			chattr -i /etc/resolv.conf ;

			# add it Cloudflare servers
			echo -e "nameserver $CLF_one\nnameserver $CLF_two" > /etc/resolv.conf ;

			# make it immutable
			chattr +i /etc/resolv.conf ;

                       # remount root in read only mode
                        mount -o remount,ro / ;

			echo -e '\n Cloudflare DNS are set up !\n'

			exit 0

		fi

		;;

	" OpenDNS")
		# search the default string
		if grep -qs 'dns=dnsmasq' /etc/NetworkManager/NetworkManager.conf

		then

			# -------------------- runs if found default dns settings -------------------- 

			# mount root in read/write mode
			mount -o remount,rw / ;

			# remove /etc/resolv.conf (is a symbolic link pointing to /run/resolvconf/resolv.conf)
			rm /etc/resolv.conf ;

			# create /etc/resolv.conf
			touch /etc/resolv.conf ;

			# add it OpenDNS servers
			echo -e "nameserver $OPE_one\nnameserver $OPE_two" >> /etc/resolv.conf ;

			# set permission
			chmod 644 /etc/resolv.conf ;

			# make it immutable
			chattr +i /etc/resolv.conf ;

			# replace dns=dnsmasq  with  dns=none in NetworkManager conf file
			sed -i 's/dns=dnsmasq/dns=none/' /etc/NetworkManager/NetworkManager.conf ;

			# remount root in read only mode
			mount -o remount,ro / ;

			echo -e '\n OpenDNS Servers are set up !\n'

			exit 0

		else

			# -------------------- runs if dns settings are already changed --------------------

			# mount root in read/write mode
			mount -o remount,rw / ;

			# makes /etc/resolv.conf writable/erasable
			chattr -i /etc/resolv.conf ;

			# add it OpenDNS servers
			echo -e "nameserver $OPE_one\nnameserver $OPE_two" > /etc/resolv.conf ;

			# make it immutable
			chattr +i /etc/resolv.conf ;

                       # remount root in read only mode
                        mount -o remount,ro / ;

			echo -e '\n OpenDNS Servers are set up !\n'

			exit 0

		fi

		;;

	" Custom DNS")
		# search the default string
		if grep -qs 'dns=dnsmasq' /etc/NetworkManager/NetworkManager.conf

		then

			# -------------------- runs if found default dns settings -------------------- 

			# mount root in read/write mode
			mount -o remount,rw / ;

			# remove /etc/resolv.conf (is a symbolic link pointing to /run/resolvconf/resolv.conf)
			rm /etc/resolv.conf ;

			# create /etc/resolv.conf
			touch /etc/resolv.conf ;

                                        read -p " Type primary server : " priDN

					echo -e "nameserver $priDN" > /etc/resolv.conf ;

					read -p " Type secondary server : " secDN

					echo -e "nameserver $secDN" >> /etc/resolv.conf ;

			# set permission
			chmod 644 /etc/resolv.conf ;

			# make it immutable
			chattr +i /etc/resolv.conf ;

			# replace dns=dnsmasq  with  dns=none in NetworkManager conf file
			sed -i 's/dns=dnsmasq/dns=none/' /etc/NetworkManager/NetworkManager.conf ;

			# remount root in read only mode
			mount -o remount,ro / ;

			echo -e '\n Custom DNS are set up !\n'

			exit 0

		else

			# -------------------- runs if dns settings are already changed --------------------

			# mount root in read/write mode
			mount -o remount,rw / ;

			# makes /etc/resolv.conf writable/erasable
			chattr -i /etc/resolv.conf ;

                                        read -p " Type primary server : " priDN

                                        echo -e "nameserver $priDN" > /etc/resolv.conf ;

                                        read -p " Type secondary server : " secDN

                                        echo -e "nameserver $secDN" >> /etc/resolv.conf ;


			# make it immutable
			chattr +i /etc/resolv.conf ;

                       # remount root in read only mode
                        mount -o remount,ro / ;

			echo -e '\n Custom DNS are set up !\n'

			exit 0

		fi

		;;

	" Restore OS")
			# mount root in read/write mode
			mount -o remount,rw / ;

			# makes /etc/resolv.conf writable/erasable
			chattr -i /etc/resolv.conf ;

			# remove it
			rm /etc/resolv.conf ;

			# recreate  original simbolic link
			ln -s /run/resolvconf/resolv.conf /etc/resolv.conf ;

			# replace dns=none  with  dns=dnsmasq in NetworkManager conf file
			sed -i 's/dns=none/dns=dnsmasq/' /etc/NetworkManager/NetworkManager.conf ;

                       # remount root in read only mode
                        mount -o remount,ro / ;

                       # restart daemon
                        service network-manager restart ;

			echo -e '\n Default settings have been restored !\n'

			exit 0

		;;
        " Quit")
			echo -e '\n OS unchanged !\n'

			break
		;;
			*) echo "invalid option $REPLY"
		;;
    esac
done
